@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.finspace 1.17.68\n"
-        "Version:         1.17.68.0\n"
-        "Builder version: 4.10.0\n"
+        "Type annotations for boto3.finspace 1.17.71\n"
+        "Version:         1.17.71\n"
+        "Builder version: 4.12.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-finspace/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/finspace.html#finspace\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.68.0")
+    print("1.17.71")
 
 
 def main() -> None:
